@@ -1,7 +1,6 @@
 package Courriel;
-{
-  $Courriel::VERSION = '0.31';
-}
+# git description: v0.35-6-g0fcadef
+$Courriel::VERSION = '0.36';
 
 use 5.10.0;
 
@@ -398,7 +397,7 @@ sub _parse {
     my $class     = shift;
     my $text      = shift;
 
-    my ( $line_sep, $sep_idx, $headers ) = $class->_parse_headers($text);
+    my ( $sep_idx, $headers ) = $class->_parse_headers($text);
 
     substr( ${$text}, 0, $sep_idx ) = q{};
 
@@ -411,7 +410,6 @@ sub _parse_headers {
 
     my $header_text;
     my $sep_idx;
-    my $line_sep;
 
     # We want to ignore mbox message separators - this is a pretty lax parser,
     # but we may find broken lines. The key is that it starts with From
@@ -423,18 +421,16 @@ sub _parse_headers {
     if ( ${$text} =~ /^(.+?)($Courriel::Helpers::LINE_SEP_RE)\g{2}/s ) {
         $header_text = $1 . $2;
         $sep_idx     = ( length $header_text ) + ( length $2 );
-        $line_sep    = $2;
     }
     else {
-        return ( q{}, 0, Courriel::Headers::->new() );
+        return ( 0, Courriel::Headers::->new() );
     }
 
     my $headers = Courriel::Headers::->parse(
-        text     => \$header_text,
-        line_sep => $line_sep,
+        text => \$header_text,
     );
 
-    return ( $line_sep, $sep_idx, $headers );
+    return ( $sep_idx, $headers );
 }
 
 {
@@ -531,7 +527,7 @@ Courriel - High level email parsing and manipulation
 
 =head1 VERSION
 
-version 0.31
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -556,6 +552,8 @@ L<Courriel::Part::Single>, and L<Courriel::Part::Multipart>. If you need lower
 level information about an email, it should be available from one of these
 classes.
 
+=encoding utf-8
+
 =head1 API
 
 This class provides the following methods:
@@ -792,13 +790,25 @@ button on this page: L<http://www.urth.org/~autarch/fs-donation.html>
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
+
+=for stopwords Gregory Oschwald Zbigniew Łukasiak
+
+=over 4
+
+=item *
+
+Gregory Oschwald <goschwald@maxmind.com>
+
+=item *
 
 Zbigniew Łukasiak <zzbbyy@gmail.com>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
