@@ -1,8 +1,5 @@
 package Courriel::Header;
-{
-  $Courriel::Header::VERSION = '0.31';
-}
-
+$Courriel::Header::VERSION = '0.36';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -67,6 +64,8 @@ sub as_string {
 {
     my $header_chunk = qr/
                              (?:
+                                 ^
+                             |
                                  (?<ascii>[\x21-\x7e]+)   # printable ASCII (excluding space, \x20)
                              |
                                  (?<non_ascii>\S+)        # anything that's not space
@@ -108,7 +107,9 @@ sub as_string {
                 push @values, q{ } if $chunks[ $i + 1 ];
             }
             else {
-                push @values, $chunks[$i]{ascii} . ( $chunks[$i]{ws} // q{} );
+                push @values,
+                    ( $chunks[$i]{ascii} // q{} )
+                    . ( $chunks[$i]{ws}  // q{} );
             }
         }
 
@@ -165,7 +166,7 @@ Courriel::Header - A single header's name and value
 
 =head1 VERSION
 
-version 0.31
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -176,6 +177,8 @@ version 0.31
 
 This class represents a single header, which consists of a name and value.
 
+=encoding utf-8
+
 =head1 API
 
 This class supports the following methods:
@@ -218,13 +221,9 @@ This class does the C<Courriel::Role::Streams> role.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
