@@ -1,8 +1,5 @@
 package Courriel::HeaderAttribute;
-{
-  $Courriel::HeaderAttribute::VERSION = '0.31';
-}
-
+$Courriel::HeaderAttribute::VERSION = '0.36';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -185,7 +182,7 @@ Courriel::HeaderAttribute - A single attribute belonging to a header
 
 =head1 VERSION
 
-version 0.31
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -197,6 +194,8 @@ version 0.31
 This class represents a single attribute belonging to a header. An attribute
 consists of a name and value, with optional charset and language information.
 
+=encoding utf-8
+
 =head1 API
 
 This class supports the following methods:
@@ -267,13 +266,9 @@ This class does the C<Courriel::Role::Streams> role.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
