@@ -1,5 +1,5 @@
 package Courriel::Headers;
-$Courriel::Headers::VERSION = '0.35';
+$Courriel::Headers::VERSION = '0.36';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -480,7 +480,7 @@ Courriel::Headers - The headers for an email part
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -617,10 +617,6 @@ This class does the C<Courriel::Role::Streams> role.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2014 by Dave Rolsky.
