@@ -1,8 +1,5 @@
 package Courriel::Part::Single;
-{
-  $Courriel::Part::Single::VERSION = '0.31';
-}
-
+$Courriel::Part::Single::VERSION = '0.36';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -212,7 +209,7 @@ Courriel::Part::Single - A part which does not contain other parts, only content
 
 =head1 VERSION
 
-version 0.31
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -227,6 +224,8 @@ version 0.31
 This class represents a single part that does not contain other parts, just
 content.
 
+=encoding utf-8
+
 =head1 API
 
 This class provides the following methods:
@@ -360,20 +359,16 @@ See the C<as_string()> method for documentation on the C<charset> parameter.
 
 =head1 ROLES
 
-This class does the C<Courriel::Role::Part> and L<Courriel::Role::Streams>
+This class does the C<Courriel::Role::Part> and C<Courriel::Role::Streams>
 roles.
 
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
