@@ -1,8 +1,5 @@
 package Email::Abstract::Courriel;
-{
-  $Email::Abstract::Courriel::VERSION = '0.31';
-}
-
+$Email::Abstract::Courriel::VERSION = '0.36';
 use strict;
 use warnings;
 
@@ -58,13 +55,15 @@ Email::Abstract::Courriel - Email::Abstract wrapper for Courriel
 
 =head1 VERSION
 
-version 0.31
+version 0.36
 
 =head1 DESCRIPTION
 
 This module wraps the Courriel mail handling library with an abstract
 interface, to be used with L<Email::Abstract>.
 
+=encoding utf-8
+
 =head1 SEE ALSO
 
 L<Email::Abstract>, L<Courriel>.
@@ -73,13 +72,9 @@ L<Email::Abstract>, L<Courriel>.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
